@@ -470,9 +470,6 @@ def main():
     if kwargs["prefs_root"] is None:
         kwargs["prefs_root"] = os.path.abspath(os.path.join(here, "prefs"))
 
-    if kwargs["metadata_root"] is None:
-        kwargs["metadata_root"] = os.path.abspath(os.path.join(here, "metadata"))
-
     setup_logging(kwargs, {"raw": sys.stdout})
 
     return run_tests(**kwargs)
